@@ -5,7 +5,7 @@ EXTERN_C const regexp_engine lua_engine;
 EXTERN_C REGEXP * Lua_comp(pTHX_ SV * const, U32);
 #if PERL_VERSION < 20
 EXTERN_C I32      Lua_exec(pTHX_ REGEXP * const, char *, char *,
-                              char *, U32, SV *, void *, U32);
+                              char *, I32, SV *, void *, U32);
 EXTERN_C char *   Lua_intuit(pTHX_ REGEXP * const, SV *, char *,
                                 char *, U32, re_scream_pos_data *);
 #else
